@@ -25,9 +25,9 @@ local_epochs = 1
 local_steps = 1
 batch_size = 4
 
-def run_global(dataset):
+def run_global(dir, dataset):
     # split data
-    dt = data_process(dataset)
+    dt = data_process(dir, dataset)
     trainset,testset = dt.train_dataset, dt.test_dataset
     net = CNNFashion_Mnist()
     net.to(device)
